==> payroll_ver_3.2.0.zip: payroll3/src/jp/mosp/common/part/TimePart.java <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.common.part;

import java.text.NumberFormat;

import jp.mosp.common.CommonConst;

/**
 * ԁAɊւPartNX
 * @author yoshida
 *	@version	0.0.2
 */
public class TimePart {

	/**
	 * int̎ԂStringɕϊ
	 * @param time
	 * @return	string	ԁij
	 */
	public static String convIntegerTimeToStringHour(int time) {
		return String.valueOf(time / 60);
	}

	/**
	 * int̕Stringɕϊ
	 * @param time
	 * @return	string	ԁij
	 */
	public static String convIntegerTimeToStringMinutes(int time) {
		return String.valueOf(time % 60);
	}

	/**
	 * String̎ԂStringɕϊ
	 * @param time HH:MM
	 * @return HH
	 */
	public static String convStringTimeToStringHour(String time) {
		if (time.equals("")) {
			return "0";
		} else {
			return convIntegerTimeToStringHour(convStringTimeToIntegerTime(time));
		}
	}

	/**
	 * String̕Stringɕϊ
	 * @param time HH:MM
	 * @return MM
	 */
	public static String convStringTimeToStringMinutes(String time) {
		if (time.equals("")) {
			return "0";
		} else {
			return convIntegerTimeToStringMinutes(convStringTimeToIntegerTime(time));
		}
	}

	/**
	 * ϊiintStringj
	 * @param time int
	 * @return HH:MM
	 */
	public static String convIntegerTimeToStringTime(int time) {
		StringBuffer sb = new StringBuffer();
		sb.append(StringPart.addZero(convIntegerTimeToStringHour(time)));
		sb.append(CommonConst.STR_TIME_SEPARATOR);
		sb.append(StringPart.addZero(convIntegerTimeToStringMinutes(time)));
		return sb.toString();
	}

	/**
	 * ϊiintStringj
	 * @param time int
	 * @return HHMM
	 */
	public static String convIntegerTimeToJPTime(int time) {
		StringBuffer sb = new StringBuffer();
		sb.append(StringPart.addZero(convIntegerTimeToStringHour(time)));
		sb.append(CommonConst.NAM_HOUR);
		sb.append(StringPart.addZero(convIntegerTimeToStringMinutes(time)));
		sb.append(CommonConst.NAM_MINUTES);
		return sb.toString();
	}

	/**
	 * ϊiStringintj
	 * @param time iHH:MMj
	 * @return int	i0̌oߕj
	 */
	public static int convStringTimeToIntegerTime(String time) {
		if (time.length() == 0) {
			time = "0:0";
		}
		String[] ar = time.split(CommonConst.STR_TIME_SEPARATOR);
		return convStringTimeToIntegerTime(ar[0], ar[1]);
	}

	/**
	 * ϊiStringintj
	 * @param hour 
	 * @param min 
	 * @return int	i0̌oߕj
	 */
	public static int convStringTimeToIntegerTime(String hour, String min) {
		return (NumberPart.getIntParam(hour) * 60) + NumberPart.getIntParam(min);
	}

	/**
	 * ϊiStringStringj
	 * @param hour 
	 * @param min 
	 * @return	HH:mm
	 */
	public static String convStringTimeFormatted(String hour, String min) {
		StringBuffer sb = new StringBuffer();
		sb.append(StringPart.addZero(hour));
		sb.append(CommonConst.STR_TIME_SEPARATOR);
		sb.append(StringPart.addZero(min));
		return sb.toString();
	}

	/**
	 * ԕϊiintdoublej
	 * @param time int
	 * @return hh.mm <br>͂̂܂
	 * 				[] 651.05
	 */
	public static double convIntegerTimeToDoubleTime(int time) {
		double dblhour = Math.floor((double)time / 60);
		double dblmin =(double)time % 60 / 100;
		double dtime = dblhour + dblmin;
		return dtime;
	}

	/**
	 * ԕϊiintStringj
	 * <p>[] 901.5</p>
	 * <p>15Pʂ̏ꍇ̂ݗpĂB</p>
	 * @param time int
	 * @return hh.mm 
	 */
	public static String convIntegerMinToStringHour(int time) {
		double dblhour = Math.floor((double)time / 60);
		double dblmin = (double)time % 60 / 60;
		double dtime = dblhour + dblmin;
		return String.valueOf(dtime);
	}

	/**
	 * ԕϊiintStringj
	 * @param time int
	 * @return HHMM
	 */
	public static String convIntegerTimeToJPHours(int time) {
		StringBuffer sb = new StringBuffer();
		sb.append(convIntegerTimeToStringHour(time));
		sb.append(CommonConst.NAM_COMMON_TIME);
		if (convIntegerTimeToStringMinutes(time).length() < 2) {
			sb.append("0");			
		}
		sb.append(convIntegerTimeToStringMinutes(time));
		sb.append(CommonConst.NAM_MINUTES);
		return sb.toString();
	}

	/**
	 * ԃtH[}bg
	 * @param hour 
	 * @return ()
	 */
	public static String getHourString(double hour) {
		NumberFormat nf = NumberFormat.getNumberInstance();
		nf.setMaximumFractionDigits(2);
		nf.setMinimumFractionDigits(2);
		return nf.format(hour);
	}

	/**
	 * ϊiintintj
	 * @since	0.0.2
	 * @param hour 
	 * @param min 
	 * @return int	i0̌oߕj
	 */
	public static int convIntegerTimeToIntegerTime(int hour, int min) {
		int times = (hour * 60) + min;
		return times;
	}

}

==> payroll_ver_3.2.1.zip: payroll3/src/jp/mosp/common/part/TimePart.java <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.common.part;

import java.text.NumberFormat;

import jp.mosp.common.CommonConst;

/**
 * ԁAɊւPartNX
 * @author yoshida
 *	@version	0.0.3
 */
public class TimePart {

	/**
	 * int̎ԂStringɕϊ
	 * @param time	i0̌oߕj
	 * @return	string	ԁij
	 */
	public static String convIntegerTimeToStringHour(int time) {
		return String.valueOf(convIntegerTimeToIntegerHour(time));
	}

	/**
	 * int̎ԂStringɕϊ
	 * @since	0.0.3
	 * @param time	i0̌oߕj
	 * @return	string	ԁij
	 */
	public static int convIntegerTimeToIntegerHour(int time) {
		return time / 60;
	}

	/**
	 * int̕Stringɕϊ
	 * @param time	i0̌oߕj
	 * @return	string	ԁij
	 */
	public static String convIntegerTimeToStringMinutes(int time) {
		return String.valueOf(convIntegerTimeToIntegerMinutes(time));
	}

	/**
	 * int̕Stringɕϊ
	 * @since	0.0.3
	 * @param time	i0̌oߕj
	 * @return	string	ԁij
	 */
	public static int convIntegerTimeToIntegerMinutes(int time) {
		return time % 60;
	}

	/**
	 * String̎ԂStringɕϊ
	 * @param time HH:MM
	 * @return HH
	 */
	public static String convStringTimeToStringHour(String time) {
		if (time.equals("")) {
			return "0";
		} else {
			return convIntegerTimeToStringHour(convStringTimeToIntegerTime(time));
		}
	}

	/**
	 * String̕Stringɕϊ
	 * @param time HH:MM
	 * @return MM
	 */
	public static String convStringTimeToStringMinutes(String time) {
		if (StringPart.isNull(time)) {
			return "0";
		} else {
			return convIntegerTimeToStringMinutes(convStringTimeToIntegerTime(time));
		}
	}

	/**
	 * ϊiintStringj
	 * @param time i0̌oߕj
	 * @return HH:MM
	 */
	public static String convIntegerTimeToStringTime(int time) {
		StringBuffer sb = new StringBuffer();
		sb.append(StringPart.addZero(convIntegerTimeToIntegerHour(time)));
		sb.append(CommonConst.STR_TIME_SEPARATOR);
		sb.append(StringPart.addZero(convIntegerTimeToIntegerMinutes(time)));
		return sb.toString();
	}

	/**
	 * ϊiintStringj
	 * @param time  i0̌oߕj
	 * @return HHMM
	 */
	public static String convIntegerTimeToJPTime(int time) {
		StringBuffer sb = new StringBuffer();
		sb.append(StringPart.addZero(convIntegerTimeToIntegerHour(time)));
		sb.append(CommonConst.NAM_HOUR);
		sb.append(StringPart.addZero(convIntegerTimeToIntegerMinutes(time)));
		sb.append(CommonConst.NAM_MINUTES);
		return sb.toString();
	}

	/**
	 * ϊiStringintj
	 * @param time iHH:MMj
	 * @return int	i0̌oߕj
	 */
	public static int convStringTimeToIntegerTime(String time) {
		String targetTime = time;
		if (StringPart.isNull(time)) {
			targetTime = "0:0";
		}
		String[] ar = targetTime.split(CommonConst.STR_TIME_SEPARATOR);
		return convStringTimeToIntegerTime(ar[0], ar[1]);
	}

	/**
	 * ϊiStringintj
	 * @param hour 
	 * @param min 
	 * @return int	i0̌oߕj
	 */
	public static int convStringTimeToIntegerTime(String hour, String min) {
		return convIntegerTimeToIntegerTime(
				NumberPart.getIntParam(hour),
				NumberPart.getIntParam(min)
		);
	}

	/**
	 * ϊiStringStringj
	 * @param hour 
	 * @param min 
	 * @return	HH:mm
	 */
	public static String convStringTimeFormatted(String hour, String min) {
		StringBuffer sb = new StringBuffer();
		sb.append(StringPart.addZero(hour));
		sb.append(CommonConst.STR_TIME_SEPARATOR);
		sb.append(StringPart.addZero(min));
		return sb.toString();
	}

	/**
	 * ԕϊiintdoublej
	 * @param time i0̌oߕj
	 * @return hh.mm <br>͂̂܂
	 * 				[] 651.05
	 */
	public static double convIntegerTimeToDoubleTime(int time) {
		double dblhour = Math.floor((double)time / 60);
		double dblmin =(double)time % 60 / 100;
		double dtime = dblhour + dblmin;
		return dtime;
	}

	/**
	 * ԕϊiintStringj
	 * <p>[] 901.5</p>
	 * <p>15Pʂ̏ꍇ̂ݗpĂB</p>
	 * @param time i0̌oߕj
	 * @return hh.mm 
	 */
	public static String convIntegerMinToStringHour(int time) {
		double dblhour = Math.floor((double)time / 60);
		double dblmin = (double)time % 60 / 60;
		double dtime = dblhour + dblmin;
		return String.valueOf(dtime);
	}

	/**
	 * ԕϊiintStringj
	 * @param time i0̌oߕj
	 * @return HHMM
	 */
	public static String convIntegerTimeToJPHours(int time) {
		StringBuffer sb = new StringBuffer();
		sb.append(convIntegerTimeToStringHour(time));
		sb.append(CommonConst.NAM_COMMON_TIME);
		sb.append(StringPart.addZero(convIntegerTimeToStringMinutes(time)));
		sb.append(CommonConst.NAM_MINUTES);
		return sb.toString();
	}

	/**
	 * ԃtH[}bg
	 * @param hour 
	 * @return ()
	 */
	public static String getHourString(double hour) {
		NumberFormat nf = NumberFormat.getNumberInstance();
		nf.setMaximumFractionDigits(2);
		nf.setMinimumFractionDigits(2);
		return nf.format(hour);
	}

	/**
	 * ϊiintintj
	 * @since	0.0.2
	 * @param hour 
	 * @param min 
	 * @return int	i0̌oߕj
	 */
	public static int convIntegerTimeToIntegerTime(int hour, int min) {
		return (hour * 60) + min;
	}

}
